@@ -22,6 +22,7 @@ PHONE_VALIDATOR = re.compile(r"\+?\d{6,}")
 PASSPORT_FILTER = re.compile(r"[^-A-Z0-9]")
 STRIP_NON_NUMBERS = re.compile(r"[^0-9]")
 STRIP_NON_ALPHANUMERIC = re.compile(r"[^0-9A-Za-z]")
+VARIABLE_NAME = re.compile(r"[^0-9A-Za-z_]")
 STRIP_WHITESPACE = re.compile(r"\s+")
 STRIP_PREFIX_ZEROS = re.compile(r"^0+")
 IBAN_FILTER = re.compile(r"[^A-Z0-9]")
@@ -111,6 +112,13 @@ def bic_sanitizer(v: str) -> str:
     return v if 8 <= len(v) <= 11 else ""
 
 
+def variable_name_sanitizer(v: str) -> str:
+    v = VARIABLE_NAME.sub("", ascii_filter(v).replace(" ", "_"))
+    if v and v[0].isdigit():
+        v = "_" + v
+    return v
+
+
 def ascii_filter(v: str) -> str:
     """
     Replaces Unicode accent characters with plain ASCII.
@@ -167,9 +175,7 @@ def iban_validator(v0: str):
     # validate prefix and length
     v = iban_filter(v0)
     if not v:
-        raise ValidationError(
-            _("Invalid IBAN account number") + " ({})".format(_("Missing value")), code="invalid_iban"
-        )
+        raise ValidationError(_("Invalid IBAN account number") + " ({})".format(_("Missing value")), code="invalid_iban")
     country = v[:2].upper()
     if country not in IBAN_LENGTH_BY_COUNTRY:
         raise ValidationError(_("Invalid country code") + " ({})".format(country), code="invalid_country_code")
@@ -198,9 +204,7 @@ def iban_generator(country_code: str = "") -> str:
     """
     # pick random country code if not set (with max IBAN length 27)
     if not country_code:
-        country_code = random.choice(  # nosec
-            list(filter(lambda cc: IBAN_LENGTH_BY_COUNTRY[cc] <= 26, IBAN_LENGTH_BY_COUNTRY.keys()))
-        )
+        country_code = random.choice(list(filter(lambda cc: IBAN_LENGTH_BY_COUNTRY[cc] <= 26, IBAN_LENGTH_BY_COUNTRY.keys())))  # nosec
     if country_code not in IBAN_LENGTH_BY_COUNTRY:
         raise ValidationError(_("Invalid country code") + " ({})".format(country_code), code="invalid_country_code")
     nlen = IBAN_LENGTH_BY_COUNTRY[country_code]
@@ -481,9 +485,7 @@ def fi_company_org_id_validator(v0: str):
     if remainder >= 2:
         check_digit = str(11 - remainder)
         if check_digit != v[-1:]:
-            raise ValidationError(
-                _("Invalid company organization ID") + " ({})".format(v0), code="invalid_company_org_id"
-            )
+            raise ValidationError(_("Invalid company organization ID") + " ({})".format(v0), code="invalid_company_org_id")
 
 
 def fi_company_org_id_generator() -> str:
